@@ -1,5 +1,5 @@
 package System::Command;
-$System::Command::VERSION = '1.112';
+$System::Command::VERSION = '1.113';
 use warnings;
 use strict;
 use 5.006;
@@ -44,13 +44,14 @@ sub import {
 }
 
 # a few simple accessors
-for my $attr (qw( pid stdin stdout stderr exit signal core options )) {
+{
     no strict 'refs';
-    *$attr = sub { return $_[0]{$attr} };
-}
-for my $attr (qw( cmdline )) {
-    no strict 'refs';
-    *$attr = sub { return @{ $_[0]{$attr} } };
+    for my $attr (qw( pid stdin stdout stderr exit signal core options )) {
+        *$attr = sub { return $_[0]{$attr} };
+    }
+    for my $attr (qw( cmdline )) {
+        *$attr = sub { return @{ $_[0]{$attr} } };
+    }
 }
 
 # REALLY PRIVATE FUNCTIONS
@@ -280,20 +281,18 @@ sub spawn {
 
 # delegate those to the reaper
 sub is_terminated { $_[0]{reaper}->is_terminated() }
-sub close         { $_[0]{reaper}->close() }
+sub close         { $_[0]{reaper}->close(); return $_[0]; }
 
 1;
 
+__END__
+
 =pod
 
 =head1 NAME
 
 System::Command - Object for running system commands
 
-=head1 VERSION
-
-version 1.112
-
 =head1 SYNOPSIS
 
     use System::Command;
@@ -439,6 +438,7 @@ the pid:
 The System::Command object returned by C<new()> has a number of
 attributes defined (see below).
 
+
 =head2 close
 
     $cmd->close;
@@ -446,6 +446,10 @@ attributes defined (see below).
 Close all pipes to the child process, collects exit status, etc.
 and defines a number of attributes (see below).
 
+Returns the invocant, so one can do things like:
+
+    my $exit = $cmd->close->exit;
+
 =head2 is_terminated
 
     if ( $cmd->is_terminated ) {...}
@@ -456,6 +460,7 @@ If the process was indeed terminated, collects exit status, etc.
 and defines the same attributes as C<close()>, but does B<not> close
 all pipes to the child process.
 
+
 =head2 spawn
 
     my ( $pid, $in, $out, $err ) = System::Command->spawn(@cmd);
@@ -464,6 +469,7 @@ This shortcut method calls C<new()> (and so accepts options in the same
 manner) and directly returns the C<pid>, C<stdin>, C<stdout> and C<stderr>
 attributes, in that order.
 
+
 =head2 Accessors
 
 The attributes of a System::Command object are also accessible
@@ -473,27 +479,27 @@ The object returned by C<new()> will have the following attributes defined:
 
 =over 4
 
-=item cmdline()
+=item cmdline
 
 Return the command-line actually executed, as a list of strings.
 
-=item options()
+=item options
 
 The merged list of options used to run the command.
 
-=item pid()
+=item pid
 
 The PID of the underlying command.
 
-=item stdin()
+=item stdin
 
 A filehandle opened in write mode to the child process' standard input.
 
-=item stdout()
+=item stdout
 
 A filehandle opened in read mode to the child process' standard output.
 
-=item stderr()
+=item stderr
 
 A filehandle opened in read mode to the child process' standard error output.
 
@@ -513,15 +519,15 @@ the following attributes will be defined:
 
 =over 4
 
-=item exit()
+=item exit
 
 The exit status of the underlying command.
 
-=item core()
+=item core
 
 A boolean value indicating if the command dumped core.
 
-=item signal()
+=item signal
 
 The signal, if any, that killed the command.
 
@@ -591,6 +597,7 @@ You can find documentation for this module with the perldoc command.
 
     perldoc System::Command
 
+
 You can also look for information at:
 
 =over 4
@@ -613,9 +620,10 @@ L<http://search.cpan.org/dist/System-Command/>
 
 =back
 
+
 =head1 COPYRIGHT
 
-Copyright 2010-2013 Philippe Bruhat (BooK).
+Copyright 2010-2015 Philippe Bruhat (BooK).
 
 =head1 LICENSE
 
@@ -627,8 +635,3 @@ See L<http://dev.perl.org/licenses/> for more information.
 
 =cut
 
-__END__
-
-# ABSTRACT: Object for running system commands
-
-
